@@ -121,6 +121,7 @@ class BBBDL:
         skip_webcam_freeze_detection: bool,
         skip_annotations: bool,
         skip_cursor: bool,
+        skip_zoom: bool,
         keep_tmp_files: bool,
         ffmpeg_location: str,
         working_dir: str,
@@ -129,12 +130,14 @@ class BBBDL:
         force_width: int,
         force_height: int,
         preset: str,
+        crf: str,
     ):
         # Rendering options
         self.skip_webcam_opt = skip_webcam
         self.skip_webcam_freeze_detection_opt = skip_webcam_freeze_detection
         self.skip_annotations_opt = skip_annotations
         self.skip_cursor_opt = skip_cursor
+        self.skip_zoom_opt = skip_zoom
         # BBB-dl Options
         self.keep_tmp_files = keep_tmp_files
         self.backup = backup
@@ -152,7 +155,7 @@ class BBBDL:
         self.slideshow_width = int(force_width) if force_width is not None else None
         self.slideshow_height = int(force_height) if force_height is not None else None
 
-        self.ffmpeg = FFMPEG(verbose, ffmpeg_location, encoder, audiocodec, preset)
+        self.ffmpeg = FFMPEG(verbose, ffmpeg_location, encoder, audiocodec, preset, crf)
 
         # Check DL-URL
         m_obj = re.match(self.VALID_URL_RE, self.dl_url)
@@ -230,11 +233,14 @@ class BBBDL:
 
         frames, only_zooms, partitions = self.parse_slides_data(loaded_shapes, metadata)
 
-        guessed_slideshow_width, guessed_slideshow_height = self.get_slideshow_size(only_zooms, deskshare_path)
-        if self.slideshow_width is None:
-            self.slideshow_width = guessed_slideshow_width
-        if self.slideshow_height is None:
-            self.slideshow_height = guessed_slideshow_height
+        if self.slideshow_width is None and self.slideshow_height is None:
+            guessed_slideshow_width, guessed_slideshow_height = self.get_slideshow_size(
+                only_zooms, deskshare_path, loaded_shapes
+            )
+            if self.slideshow_width is None:
+                self.slideshow_width = guessed_slideshow_width
+            if self.slideshow_height is None:
+                self.slideshow_height = guessed_slideshow_height
 
         self.create_frames(frames, only_zooms, partitions)
 
@@ -272,7 +278,7 @@ class BBBDL:
         result_list = sorted(result_list, key=lambda item: item.start_timestamp)
         return result_list
 
-    def get_slideshow_size(self, only_zooms: Dict[float, Frame], deskshare_path: str):
+    def get_slideshow_size(self, only_zooms: Dict[float, Frame], deskshare_path: str, loaded_shapes: Element):
         widths = []
         heights = []
         if deskshare_path is not None:
@@ -280,10 +286,17 @@ class BBBDL:
             widths.append(video_info.width)
             heights.append(video_info.height)
 
-        for _, frame in only_zooms.items():
-            action = frame.actions[0]
-            widths.append(int(action.width))
-            heights.append(int(action.height))
+        if self.skip_zoom_opt:
+            # Use slides sizes as frame resolution
+            slides_widths, slides_heights = self.get_all_slide_sizes(loaded_shapes)
+            widths.extend(slides_widths)
+            heights.extend(slides_heights)
+        else:
+            # Use zoom view box size as frame resolution
+            for _, frame in only_zooms.items():
+                action = frame.actions[0]
+                widths.append(int(action.width))
+                heights.append(int(action.height))
 
         if len(widths) == 0 or len(heights) == 0:
             return
@@ -398,6 +411,8 @@ class BBBDL:
         async with semaphore, async_playwright() as p:
             first_timestamp = partition[0]
             last_timestamp = partition[1]
+
+            # Check if partition is already done
             partition_already_done = True
             total_frames_in_partition = 0
             for timestamp, frame in frames.items():
@@ -431,12 +446,15 @@ class BBBDL:
             }"""
             )
             current_view_box = None
+            # Set initial view box for this partition
             for timestamp, frame in only_zooms.items():
                 if timestamp > first_timestamp:
                     continue
                 # We only set one initial ViewBox, the first we find before the partition
                 current_view_box = frame.actions[0]
-                await self.set_view_box(page, current_view_box)
+                if not self.skip_zoom_opt:
+                    # Use this view box only if we want to zoom
+                    await self.set_view_box(page, current_view_box)
                 break
             for timestamp, frame in frames.items():
                 if timestamp > last_timestamp:
@@ -447,6 +465,17 @@ class BBBDL:
                     if action.action_type == ActionType.show_image:
                         await self.show_image(page, action)
                         await self.show_cursor(page)
+                        if self.skip_zoom_opt:
+                            # Use custom view box if we do not want to zoom
+                            zoom_action = Action(
+                                action_type=ActionType.set_view_box,
+                                value=f"0 0 {action.width} {action.height}",
+                                x=0,
+                                y=0,
+                                width=action.width,
+                                height=action.height,
+                            )
+                            await self.set_view_box(page, zoom_action)
                     elif action.action_type == ActionType.hide_image:
                         await self.hide_image(page, action)
                         await self.hide_cursor(page)
@@ -456,7 +485,9 @@ class BBBDL:
                         await self.hide_drawing(page, action)
                     elif action.action_type == ActionType.set_view_box:
                         current_view_box = action
-                        await self.set_view_box(page, action)
+                        if not self.skip_zoom_opt:
+                            # Use this view box only if we want to zoom
+                            await self.set_view_box(page, action)
                     elif action.action_type == ActionType.move_cursor:
                         if current_view_box is None:
                             Log.warning('No ViewBox, cursor position unclear!')
@@ -520,11 +551,6 @@ class BBBDL:
         )  # Maybe use visibility?
 
     async def set_view_box(self, page: Page, action: Action):
-        # scale_w = ow
-        # scale_h = trunc(ow/a/2)*2
-        # abs_pos_x =  (ow-scale_w)/2
-        # abs_pos_y = (oh-scale_h)/2
-
         # First try to use whole slideshow width
         aspect_ratio = action.width / action.height
         width = self.slideshow_width
@@ -536,6 +562,7 @@ class BBBDL:
             height = self.slideshow_height
             width = int(math.trunc(height / aspect_ratio / 2) * 2)
 
+        # Center the slide on the screen
         pos_x = int((self.slideshow_width - width) / 2)
         pos_y = int((self.slideshow_height - height) / 2)
         await page.evaluate(
@@ -574,7 +601,7 @@ class BBBDL:
             [x, y],
         )
 
-    def get_all_image_urls(self, loaded_shapes: Element) -> List[str]:
+    def get_all_image_urls(self, loaded_shapes: Element) -> (List[str], List[Tuple[int]]):
         image_urls = []
         shapes_images = loaded_shapes.findall(_s(".//svg:image"))
         for image in shapes_images:
@@ -583,6 +610,17 @@ class BBBDL:
                 image_urls.append(image_rel_path)
         return image_urls
 
+    def get_all_slide_sizes(self, loaded_shapes: Element) -> (List[int], List[int]):
+        widths = []
+        heights = []
+        slides = loaded_shapes.findall(_s("./svg:image[@class='slide']"))
+        for image in slides:
+            image_width = int(float(image.get('width')))
+            image_height = int(float(image.get('height')))
+            widths.append(image_width)
+            heights.append(image_height)
+        return widths, heights
+
     def parse_metadata(self) -> Metadata:
         loaded_metadata = self.load_xml('metadata.xml')
 
@@ -1159,20 +1197,27 @@ def get_parser():
         help='Skip detecting if the webcam video is completely empty.'
         + ' It is assumed the webcam recording is not empty. This will reduce the time to generate the final video',
     )
-
     parser.add_argument(
         '-sa',
         '--skip-annotations',
         action='store_true',
         help='Skip capturing the annotations of the professor. This will reduce the time to generate the final video',
     )
-
     parser.add_argument(
         '-sc',
         '--skip-cursor',
         action='store_true',
         help='Skip capturing the cursor of the professor. This will reduce the time to generate the final video',
     )
+    parser.add_argument(
+        '-sz',
+        '--skip-zoom',
+        action='store_true',
+        help=(
+            'Skip zooming into the presentation. All presentation slides are rendered in full size,'
+            + ' which may result in sharper output video. However, consequently also to smaller font.'
+        ),
+    )
 
     parser.add_argument(
         '-bk',
@@ -1244,6 +1289,16 @@ def get_parser():
         default='fast',
         help='Optional preset to pass to ffmpeg (default fast, a preset that can be used with all encoders)',
     )
+    parser.add_argument(
+        '--crf',
+        dest='crf',
+        type=int,
+        default=23,
+        help=(
+            'Optional crf to pass to ffmpeg'
+            + ' (default 23, lower crf (e.g 22) usually means larger file size and better video quality)'
+        ),
+    )
 
     parser.add_argument(
         '-f',
@@ -1315,6 +1370,7 @@ def main(args=None):
             args.skip_webcam_freeze_detection,
             args.skip_annotations,
             args.skip_cursor,
+            args.skip_zoom,
             args.keep_tmp_files,
             args.ffmpeg_location,
             args.working_dir,
@@ -1323,5 +1379,6 @@ def main(args=None):
             args.force_width,
             args.force_height,
             args.preset,
+            args.crf,
         ).run()
     Log.info(f'BBB-DL finished and took: {formatSeconds(final_t.duration)}')
